@@ -44,6 +44,8 @@ public interface ScenarioSimulationEditorConstants
 
     String remove();
 
+    String currentlyNotAvailable();
+
     String invalidDefinitionDisabled();
 
     String testTools();
@@ -144,6 +146,12 @@ public interface ScenarioSimulationEditorConstants
 
     String dmnCheatSheet18();
 
+    String dmnCheatSheet19();
+
+    String dmnCheatSheet20();
+
+    String dmnCheatSheet21();
+
     String forExample();
 
     String runScenarioSimulation();
@@ -264,6 +272,12 @@ public interface ScenarioSimulationEditorConstants
 
     String dmnPathErrorLabel(String dmnPath);
 
+    String dmnPathErrorDetailedLabel(String dmnPath);
+
+    String missingSelectedType();
+
+    String missingDmnPath();
+
     String coverageReport();
 
     String uploadWarning();
@@ -364,6 +378,8 @@ public interface ScenarioSimulationEditorConstants
 
     String commonCheatSheetBackground(String background, String model);
 
+    String createButton();
+
     String saveButton();
 
     String removeButton();
